CSVResultTracker
================

.. currentmodule:: pykeen.trackers

.. autoclass:: CSVResultTracker
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CSVResultTracker.HEADER
      ~CSVResultTracker.extension

   .. rubric:: Methods Summary

   .. autosummary::

      ~CSVResultTracker.log_metrics
      ~CSVResultTracker.log_params
      ~CSVResultTracker.start_run

   .. rubric:: Attributes Documentation

   .. autoattribute:: HEADER
   .. autoattribute:: extension

   .. rubric:: Methods Documentation

   .. automethod:: log_metrics
   .. automethod:: log_params
   .. automethod:: start_run
